var indexSectionsWithContent =
{
  0: "acgijmpqsv",
  1: "j",
  2: "jq",
  3: "acgmps",
  4: "ijv",
  5: "j",
  6: "j"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "groups",
  6: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Modules",
  6: "Pages"
};

